@@ -1,3 +1,4 @@
+#![allow(unused_imports)]
 #![warn(missing_docs)]
 //! Parses a `Vec<u8>` as an byte sequence with ansi colors to
 //! [`tui::text::Text`][Text].  
@@ -17,18 +18,19 @@
 //! The argument to the function `ansi_to_text` implements `IntoIterator` so it will be consumed on
 //! use.
 //! ```rust
-//! use ansi_to_tui::ansi_to_text;
+//! # fn doctest() -> eyre::Result<()> {
+//! use ansi_to_tui::IntoText as _;
 //! let bytes = b"\x1b[38;2;225;192;203mAAAAA\x1b[0m".to_owned().to_vec();
-//! let text = ansi_to_text(bytes).unwrap();
+//! let text = bytes.into_text()?;
+//! # Ok(()) }
 //! ```
 //! Example parsing from a file.
 //! ```rust
-//! use ansi_to_tui::ansi_to_text;
-//! use std::io::Read;
-//!
-//! let file = std::fs::File::open("text.ascii");
-//! let mut buffer: Vec<u8> = Vec::new();
-//! let text = ansi_to_text(buffer);
+//! # fn doctest() -> eyre::Result<()> {
+//! use ansi_to_tui::IntoText as _;
+//! let buffer = std::fs::read("ascii/text.ascii")?;
+//! let text = buffer.into_text()?;
+//! # Ok(()) }
 //! ```
 //!
 //! If you want to use [`simdutf8`][simdutf8] instead of `String::from_utf8()`  
@@ -38,11 +40,32 @@
 //! [ansi-to-tui]: https://github.com/uttarayan21/ansi-to-tui
 //! [simdutf8]: https://github.com/rusticstuff/simdutf8
 
-mod ansi;
+// mod ansi;
 mod code;
 mod error;
-mod stack;
-
-pub use ansi::{ansi_to_text, ansi_to_text_override_style};
-pub use code::AnsiCode;
+mod parser;
 pub use error::Error;
+use ratatui_core::text::Text;
+
+/// IntoText will convert any type that has a AsRef<[u8]> to a Text.
+pub trait IntoText {
+    /// Convert the type to a Text.
+    #[allow(clippy::wrong_self_convention)]
+    fn into_text(&self) -> Result<Text<'static>, Error>;
+    /// Convert the type to a Text while trying to copy as less as possible
+    #[cfg(feature = "zero-copy")]
+    fn to_text(&self) -> Result<Text<'_>, Error>;
+}
+impl<T> IntoText for T
+where
+    T: AsRef<[u8]>,
+{
+    fn into_text(&self) -> Result<Text<'static>, Error> {
+        Ok(crate::parser::text(self.as_ref())?.1)
+    }
+
+    #[cfg(feature = "zero-copy")]
+    fn to_text(&self) -> Result<Text<'_>, Error> {
+        Ok(crate::parser::text_fast(self.as_ref())?.1)
+    }
+}
